@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: yesod-auth
 version: 1.4.12
-id: yesod-auth-1.4.12-cc89ddaa1d8ceca602ee7d4484044559
-key: yesod_7e4i3MW62lU0DGlKuBXqYp
+id: yesod-auth-1.4.12-ee3d41f28307a05c0f72f6763eadee03
+key: yesod_3eSDIaHak3TFsktL8dQ8nb
 license: MIT
 maintainer: Michael Snoyman <michael@snoyman.com>
 stability: Stable
@@ -23,10 +23,10 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/yesod-auth-1.4.12
 library-dirs: /usr/lib/ghc-7.10.3/site-local/yesod-auth-1.4.12
 data-dir: /usr/share/arm-linux-ghc-7.10.3/yesod-auth-1.4.12
-hs-libraries: HSyesod-auth-1.4.12-7e4i3MW62lU0DGlKuBXqYp
+hs-libraries: HSyesod-auth-1.4.12-3eSDIaHak3TFsktL8dQ8nb
 depends:
-    aeson-0.10.0.0-d37842f030fec47bc6e0ba2aef0f6571
-    authenticate-1.3.3-e1786589aa33ebec7643f5494d2d4c58
+    aeson-0.11.1.0-9c8ef4d36b55b55b3762b9041f2dfc23
+    authenticate-1.3.3-a8c6eafded1415556529a09f6f8cf0a0
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     base16-bytestring-0.1.1.6-2ce49c0fdad8d57abae997bf0287241a
     base64-bytestring-1.0.0.1-7819850819049320f81b6417431cc8a5
@@ -36,35 +36,35 @@ depends:
     blaze-markup-0.7.0.3-4e4a97653c712eed9984271000636729
     byteable-0.1.1-b91304cc70dc43f4dc186dc9711b3917
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
-    conduit-1.2.6.1-20c379c1e33e978c5d5c8f5ef78dd0c3
-    conduit-extra-1.1.9.2-aa4a80a63306500e6d6a1edce4badfdd
+    conduit-1.2.6.2-e9736ac2851958c9940f374454cdc4fe
+    conduit-extra-1.1.10.1-e4383b2e14cc80179dd5007ca51887df
     containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
-    cryptohash-0.11.6-e28406db011dea16e99b7bc1708b91dc
+    cryptohash-0.11.7-d9e0f8e58e69d0717d29fde3802983d0
     data-default-0.5.3-a34fab0e414a3e31b9dccb1774520fca
     email-validate-2.2.0-894e6c8f7fbbeb1604af196a15c5e993
     file-embed-0.0.9.1-490f794ac7ce2cc242aa3be8fec9767e
-    http-client-0.4.27-cb2c2811d5497a3b5f8310fdf3cadc3f
-    http-conduit-2.1.8-e2c4d8f7b8297fdf1ac5b7f32d06d5dd
+    http-client-0.4.27-6347f4775f754bcb55a202aff6332b65
+    http-conduit-2.1.8-7af4c72b658e9ba872144aa8bca2c27b
     http-types-0.9-d392878af9c5e1b1993961dc71a9e177
     lifted-base-0.2.3.6-26b5b3c50c56a653ba3c5b8bce492107
     mime-mail-0.4.11-159ba13f631e4ac9bb3254d1bcac4f3d
     network-uri-2.6.0.3-27316eb865f3b3562ae77903534d67a4
     nonce-1.0.2-ba2a4fc59a4ebf1fc9363b2dcb9c988b
-    persistent-2.2.4-3efd0b27ba9bd4f18bae3621104638b2
-    persistent-template-2.1.5-8e80a31cb67cc3ef9d0a8d75e0beb774
+    persistent-2.2.4-72be3212e3a1e06e6072e64a9625ec8e
+    persistent-template-2.1.5-8c3ce51da960caf9734845ba2763f466
     random-1.1-41a0a7ecd483c665a5c3a093a5be2968
-    resourcet-1.1.7.1-34b9e931a3d19e984bea5de562a18bbd
+    resourcet-1.1.7.2-b95e5d14f30eaa21587bc62eeb9aed0c
     safe-0.3.9-b613242f536083d5bb04920ede356aea
-    shakespeare-2.0.7-3d8247ff57d7f10558308bd73d118ae2
+    shakespeare-2.0.7-299569683f963ce6b42dbe4d7cdb1dae
     template-haskell-2.10.0.0-4b92ab565139fd81021b60a162b59eb8
     text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
     time-1.5.0.1-cf94b0d806e26f6c4e356671290061b2
     transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
-    unordered-containers-0.2.6.0-2907cc2989779dea3b04f8a0a144a8a7
-    wai-3.2.0-ef5213f36cb00369a3d68c2dd00424b9
-    yesod-core-1.4.19-97e13dc735e6c4c26d8664b1b0881662
-    yesod-form-1.4.6-f33925874fe42e8068b104bdcab5984d
-    yesod-persistent-1.4.0.3-b0d59ef575a9f5abbc9cd66ae1d954b9
+    unordered-containers-0.2.7.0-03f1d2fb96e30aca19bb1467e9476c22
+    wai-3.2.0-61d8ab991e10dd6c5057d0dabf632d2a
+    yesod-core-1.4.19-25fb856b7d20f03518ef74f7c04b9148
+    yesod-form-1.4.6-1f5bbab0daee91a31c9792276fdb63be
+    yesod-persistent-1.4.0.3-94cd901c0d8cf92080c629833de6573c
 haddock-interfaces: /usr/share/doc/haskell-yesod-auth/html/yesod-auth.haddock
 haddock-html: /usr/share/doc/haskell-yesod-auth/html
 ' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
